==> cdktf-provider-aws-10.0.5-sources.jar: com/hashicorp/cdktf/providers/aws/codedeploy_deployment_group/CodedeployDeploymentGroupBlueGreenDeploymentConfig.java <==
package com.hashicorp.cdktf.providers.aws.codedeploy_deployment_group;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.69.0 (build f656c31)", date = "2022-10-07T01:25:52.144Z")
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.aws.$Module.class, fqn = "@cdktf/provider-aws.codedeployDeploymentGroup.CodedeployDeploymentGroupBlueGreenDeploymentConfig")
@software.amazon.jsii.Jsii.Proxy(CodedeployDeploymentGroupBlueGreenDeploymentConfig.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CodedeployDeploymentGroupBlueGreenDeploymentConfig extends software.amazon.jsii.JsiiSerializable {

    /**
     * deployment_ready_option block.
     * <p>
     * Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/aws/r/codedeploy_deployment_group#deployment_ready_option CodedeployDeploymentGroup#deployment_ready_option}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.aws.codedeploy_deployment_group.CodedeployDeploymentGroupBlueGreenDeploymentConfigDeploymentReadyOption getDeploymentReadyOption() {
        return null;
    }

    /**
     * green_fleet_provisioning_option block.
     * <p>
     * Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/aws/r/codedeploy_deployment_group#green_fleet_provisioning_option CodedeployDeploymentGroup#green_fleet_provisioning_option}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.aws.codedeploy_deployment_group.CodedeployDeploymentGroupBlueGreenDeploymentConfigGreenFleetProvisioningOption getGreenFleetProvisioningOption() {
        return null;
    }

    /**
     * terminate_blue_instances_on_deployment_success block.
     * <p>
     * Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/aws/r/codedeploy_deployment_group#terminate_blue_instances_on_deployment_success CodedeployDeploymentGroup#terminate_blue_instances_on_deployment_success}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.aws.codedeploy_deployment_group.CodedeployDeploymentGroupBlueGreenDeploymentConfigTerminateBlueInstancesOnDeploymentSuccess getTerminateBlueInstancesOnDeploymentSuccess() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link CodedeployDeploymentGroupBlueGreenDeploymentConfig}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CodedeployDeploymentGroupBlueGreenDeploymentConfig}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<CodedeployDeploymentGroupBlueGreenDeploymentConfig> {
        com.hashicorp.cdktf.providers.aws.codedeploy_deployment_group.CodedeployDeploymentGroupBlueGreenDeploymentConfigDeploymentReadyOption deploymentReadyOption;
        com.hashicorp.cdktf.providers.aws.codedeploy_deployment_group.CodedeployDeploymentGroupBlueGreenDeploymentConfigGreenFleetProvisioningOption greenFleetProvisioningOption;
        com.hashicorp.cdktf.providers.aws.codedeploy_deployment_group.CodedeployDeploymentGroupBlueGreenDeploymentConfigTerminateBlueInstancesOnDeploymentSuccess terminateBlueInstancesOnDeploymentSuccess;

        /**
         * Sets the value of {@link CodedeployDeploymentGroupBlueGreenDeploymentConfig#getDeploymentReadyOption}
         * @param deploymentReadyOption deployment_ready_option block.
         *                              Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/aws/r/codedeploy_deployment_group#deployment_ready_option CodedeployDeploymentGroup#deployment_ready_option}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder deploymentReadyOption(com.hashicorp.cdktf.providers.aws.codedeploy_deployment_group.CodedeployDeploymentGroupBlueGreenDeploymentConfigDeploymentReadyOption deploymentReadyOption) {
            this.deploymentReadyOption = deploymentReadyOption;
            return this;
        }

        /**
         * Sets the value of {@link CodedeployDeploymentGroupBlueGreenDeploymentConfig#getGreenFleetProvisioningOption}
         * @param greenFleetProvisioningOption green_fleet_provisioning_option block.
         *                                     Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/aws/r/codedeploy_deployment_group#green_fleet_provisioning_option CodedeployDeploymentGroup#green_fleet_provisioning_option}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder greenFleetProvisioningOption(com.hashicorp.cdktf.providers.aws.codedeploy_deployment_group.CodedeployDeploymentGroupBlueGreenDeploymentConfigGreenFleetProvisioningOption greenFleetProvisioningOption) {
            this.greenFleetProvisioningOption = greenFleetProvisioningOption;
            return this;
        }

        /**
         * Sets the value of {@link CodedeployDeploymentGroupBlueGreenDeploymentConfig#getTerminateBlueInstancesOnDeploymentSuccess}
         * @param terminateBlueInstancesOnDeploymentSuccess terminate_blue_instances_on_deployment_success block.
         *                                                  Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/aws/r/codedeploy_deployment_group#terminate_blue_instances_on_deployment_success CodedeployDeploymentGroup#terminate_blue_instances_on_deployment_success}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder terminateBlueInstancesOnDeploymentSuccess(com.hashicorp.cdktf.providers.aws.codedeploy_deployment_group.CodedeployDeploymentGroupBlueGreenDeploymentConfigTerminateBlueInstancesOnDeploymentSuccess terminateBlueInstancesOnDeploymentSuccess) {
            this.terminateBlueInstancesOnDeploymentSuccess = terminateBlueInstancesOnDeploymentSuccess;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CodedeployDeploymentGroupBlueGreenDeploymentConfig}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public CodedeployDeploymentGroupBlueGreenDeploymentConfig build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link CodedeployDeploymentGroupBlueGreenDeploymentConfig}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CodedeployDeploymentGroupBlueGreenDeploymentConfig {
        private final com.hashicorp.cdktf.providers.aws.codedeploy_deployment_group.CodedeployDeploymentGroupBlueGreenDeploymentConfigDeploymentReadyOption deploymentReadyOption;
        private final com.hashicorp.cdktf.providers.aws.codedeploy_deployment_group.CodedeployDeploymentGroupBlueGreenDeploymentConfigGreenFleetProvisioningOption greenFleetProvisioningOption;
        private final com.hashicorp.cdktf.providers.aws.codedeploy_deployment_group.CodedeployDeploymentGroupBlueGreenDeploymentConfigTerminateBlueInstancesOnDeploymentSuccess terminateBlueInstancesOnDeploymentSuccess;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.deploymentReadyOption = software.amazon.jsii.Kernel.get(this, "deploymentReadyOption", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.aws.codedeploy_deployment_group.CodedeployDeploymentGroupBlueGreenDeploymentConfigDeploymentReadyOption.class));
            this.greenFleetProvisioningOption = software.amazon.jsii.Kernel.get(this, "greenFleetProvisioningOption", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.aws.codedeploy_deployment_group.CodedeployDeploymentGroupBlueGreenDeploymentConfigGreenFleetProvisioningOption.class));
            this.terminateBlueInstancesOnDeploymentSuccess = software.amazon.jsii.Kernel.get(this, "terminateBlueInstancesOnDeploymentSuccess", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.aws.codedeploy_deployment_group.CodedeployDeploymentGroupBlueGreenDeploymentConfigTerminateBlueInstancesOnDeploymentSuccess.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.deploymentReadyOption = builder.deploymentReadyOption;
            this.greenFleetProvisioningOption = builder.greenFleetProvisioningOption;
            this.terminateBlueInstancesOnDeploymentSuccess = builder.terminateBlueInstancesOnDeploymentSuccess;
        }

        @Override
        public final com.hashicorp.cdktf.providers.aws.codedeploy_deployment_group.CodedeployDeploymentGroupBlueGreenDeploymentConfigDeploymentReadyOption getDeploymentReadyOption() {
            return this.deploymentReadyOption;
        }

        @Override
        public final com.hashicorp.cdktf.providers.aws.codedeploy_deployment_group.CodedeployDeploymentGroupBlueGreenDeploymentConfigGreenFleetProvisioningOption getGreenFleetProvisioningOption() {
            return this.greenFleetProvisioningOption;
        }

        @Override
        public final com.hashicorp.cdktf.providers.aws.codedeploy_deployment_group.CodedeployDeploymentGroupBlueGreenDeploymentConfigTerminateBlueInstancesOnDeploymentSuccess getTerminateBlueInstancesOnDeploymentSuccess() {
            return this.terminateBlueInstancesOnDeploymentSuccess;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getDeploymentReadyOption() != null) {
                data.set("deploymentReadyOption", om.valueToTree(this.getDeploymentReadyOption()));
            }
            if (this.getGreenFleetProvisioningOption() != null) {
                data.set("greenFleetProvisioningOption", om.valueToTree(this.getGreenFleetProvisioningOption()));
            }
            if (this.getTerminateBlueInstancesOnDeploymentSuccess() != null) {
                data.set("terminateBlueInstancesOnDeploymentSuccess", om.valueToTree(this.getTerminateBlueInstancesOnDeploymentSuccess()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@cdktf/provider-aws.codedeployDeploymentGroup.CodedeployDeploymentGroupBlueGreenDeploymentConfig"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CodedeployDeploymentGroupBlueGreenDeploymentConfig.Jsii$Proxy that = (CodedeployDeploymentGroupBlueGreenDeploymentConfig.Jsii$Proxy) o;

            if (this.deploymentReadyOption != null ? !this.deploymentReadyOption.equals(that.deploymentReadyOption) : that.deploymentReadyOption != null) return false;
            if (this.greenFleetProvisioningOption != null ? !this.greenFleetProvisioningOption.equals(that.greenFleetProvisioningOption) : that.greenFleetProvisioningOption != null) return false;
            return this.terminateBlueInstancesOnDeploymentSuccess != null ? this.terminateBlueInstancesOnDeploymentSuccess.equals(that.terminateBlueInstancesOnDeploymentSuccess) : that.terminateBlueInstancesOnDeploymentSuccess == null;
        }

        @Override
        public final int hashCode() {
            int result = this.deploymentReadyOption != null ? this.deploymentReadyOption.hashCode() : 0;
            result = 31 * result + (this.greenFleetProvisioningOption != null ? this.greenFleetProvisioningOption.hashCode() : 0);
            result = 31 * result + (this.terminateBlueInstancesOnDeploymentSuccess != null ? this.terminateBlueInstancesOnDeploymentSuccess.hashCode() : 0);
            return result;
        }
    }
}

==> cdktf-provider-aws-16.0.4-sources.jar: com/hashicorp/cdktf/providers/aws/codedeploy_deployment_group/CodedeployDeploymentGroupBlueGreenDeploymentConfig.java <==
package com.hashicorp.cdktf.providers.aws.codedeploy_deployment_group;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.85.0 (build 08ee592)", date = "2023-07-21T05:23:07.938Z")
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.aws.$Module.class, fqn = "@cdktf/provider-aws.codedeployDeploymentGroup.CodedeployDeploymentGroupBlueGreenDeploymentConfig")
@software.amazon.jsii.Jsii.Proxy(CodedeployDeploymentGroupBlueGreenDeploymentConfig.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CodedeployDeploymentGroupBlueGreenDeploymentConfig extends software.amazon.jsii.JsiiSerializable {

    /**
     * deployment_ready_option block.
     * <p>
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/codedeploy_deployment_group#deployment_ready_option CodedeployDeploymentGroup#deployment_ready_option}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.aws.codedeploy_deployment_group.CodedeployDeploymentGroupBlueGreenDeploymentConfigDeploymentReadyOption getDeploymentReadyOption() {
        return null;
    }

    /**
     * green_fleet_provisioning_option block.
     * <p>
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/codedeploy_deployment_group#green_fleet_provisioning_option CodedeployDeploymentGroup#green_fleet_provisioning_option}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.aws.codedeploy_deployment_group.CodedeployDeploymentGroupBlueGreenDeploymentConfigGreenFleetProvisioningOption getGreenFleetProvisioningOption() {
        return null;
    }

    /**
     * terminate_blue_instances_on_deployment_success block.
     * <p>
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/codedeploy_deployment_group#terminate_blue_instances_on_deployment_success CodedeployDeploymentGroup#terminate_blue_instances_on_deployment_success}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.aws.codedeploy_deployment_group.CodedeployDeploymentGroupBlueGreenDeploymentConfigTerminateBlueInstancesOnDeploymentSuccess getTerminateBlueInstancesOnDeploymentSuccess() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link CodedeployDeploymentGroupBlueGreenDeploymentConfig}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CodedeployDeploymentGroupBlueGreenDeploymentConfig}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<CodedeployDeploymentGroupBlueGreenDeploymentConfig> {
        com.hashicorp.cdktf.providers.aws.codedeploy_deployment_group.CodedeployDeploymentGroupBlueGreenDeploymentConfigDeploymentReadyOption deploymentReadyOption;
        com.hashicorp.cdktf.providers.aws.codedeploy_deployment_group.CodedeployDeploymentGroupBlueGreenDeploymentConfigGreenFleetProvisioningOption greenFleetProvisioningOption;
        com.hashicorp.cdktf.providers.aws.codedeploy_deployment_group.CodedeployDeploymentGroupBlueGreenDeploymentConfigTerminateBlueInstancesOnDeploymentSuccess terminateBlueInstancesOnDeploymentSuccess;

        /**
         * Sets the value of {@link CodedeployDeploymentGroupBlueGreenDeploymentConfig#getDeploymentReadyOption}
         * @param deploymentReadyOption deployment_ready_option block.
         *                              Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/codedeploy_deployment_group#deployment_ready_option CodedeployDeploymentGroup#deployment_ready_option}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder deploymentReadyOption(com.hashicorp.cdktf.providers.aws.codedeploy_deployment_group.CodedeployDeploymentGroupBlueGreenDeploymentConfigDeploymentReadyOption deploymentReadyOption) {
            this.deploymentReadyOption = deploymentReadyOption;
            return this;
        }

        /**
         * Sets the value of {@link CodedeployDeploymentGroupBlueGreenDeploymentConfig#getGreenFleetProvisioningOption}
         * @param greenFleetProvisioningOption green_fleet_provisioning_option block.
         *                                     Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/codedeploy_deployment_group#green_fleet_provisioning_option CodedeployDeploymentGroup#green_fleet_provisioning_option}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder greenFleetProvisioningOption(com.hashicorp.cdktf.providers.aws.codedeploy_deployment_group.CodedeployDeploymentGroupBlueGreenDeploymentConfigGreenFleetProvisioningOption greenFleetProvisioningOption) {
            this.greenFleetProvisioningOption = greenFleetProvisioningOption;
            return this;
        }

        /**
         * Sets the value of {@link CodedeployDeploymentGroupBlueGreenDeploymentConfig#getTerminateBlueInstancesOnDeploymentSuccess}
         * @param terminateBlueInstancesOnDeploymentSuccess terminate_blue_instances_on_deployment_success block.
         *                                                  Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/codedeploy_deployment_group#terminate_blue_instances_on_deployment_success CodedeployDeploymentGroup#terminate_blue_instances_on_deployment_success}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder terminateBlueInstancesOnDeploymentSuccess(com.hashicorp.cdktf.providers.aws.codedeploy_deployment_group.CodedeployDeploymentGroupBlueGreenDeploymentConfigTerminateBlueInstancesOnDeploymentSuccess terminateBlueInstancesOnDeploymentSuccess) {
            this.terminateBlueInstancesOnDeploymentSuccess = terminateBlueInstancesOnDeploymentSuccess;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CodedeployDeploymentGroupBlueGreenDeploymentConfig}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public CodedeployDeploymentGroupBlueGreenDeploymentConfig build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link CodedeployDeploymentGroupBlueGreenDeploymentConfig}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CodedeployDeploymentGroupBlueGreenDeploymentConfig {
        private final com.hashicorp.cdktf.providers.aws.codedeploy_deployment_group.CodedeployDeploymentGroupBlueGreenDeploymentConfigDeploymentReadyOption deploymentReadyOption;
        private final com.hashicorp.cdktf.providers.aws.codedeploy_deployment_group.CodedeployDeploymentGroupBlueGreenDeploymentConfigGreenFleetProvisioningOption greenFleetProvisioningOption;
        private final com.hashicorp.cdktf.providers.aws.codedeploy_deployment_group.CodedeployDeploymentGroupBlueGreenDeploymentConfigTerminateBlueInstancesOnDeploymentSuccess terminateBlueInstancesOnDeploymentSuccess;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.deploymentReadyOption = software.amazon.jsii.Kernel.get(this, "deploymentReadyOption", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.aws.codedeploy_deployment_group.CodedeployDeploymentGroupBlueGreenDeploymentConfigDeploymentReadyOption.class));
            this.greenFleetProvisioningOption = software.amazon.jsii.Kernel.get(this, "greenFleetProvisioningOption", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.aws.codedeploy_deployment_group.CodedeployDeploymentGroupBlueGreenDeploymentConfigGreenFleetProvisioningOption.class));
            this.terminateBlueInstancesOnDeploymentSuccess = software.amazon.jsii.Kernel.get(this, "terminateBlueInstancesOnDeploymentSuccess", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.aws.codedeploy_deployment_group.CodedeployDeploymentGroupBlueGreenDeploymentConfigTerminateBlueInstancesOnDeploymentSuccess.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.deploymentReadyOption = builder.deploymentReadyOption;
            this.greenFleetProvisioningOption = builder.greenFleetProvisioningOption;
            this.terminateBlueInstancesOnDeploymentSuccess = builder.terminateBlueInstancesOnDeploymentSuccess;
        }

        @Override
        public final com.hashicorp.cdktf.providers.aws.codedeploy_deployment_group.CodedeployDeploymentGroupBlueGreenDeploymentConfigDeploymentReadyOption getDeploymentReadyOption() {
            return this.deploymentReadyOption;
        }

        @Override
        public final com.hashicorp.cdktf.providers.aws.codedeploy_deployment_group.CodedeployDeploymentGroupBlueGreenDeploymentConfigGreenFleetProvisioningOption getGreenFleetProvisioningOption() {
            return this.greenFleetProvisioningOption;
        }

        @Override
        public final com.hashicorp.cdktf.providers.aws.codedeploy_deployment_group.CodedeployDeploymentGroupBlueGreenDeploymentConfigTerminateBlueInstancesOnDeploymentSuccess getTerminateBlueInstancesOnDeploymentSuccess() {
            return this.terminateBlueInstancesOnDeploymentSuccess;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getDeploymentReadyOption() != null) {
                data.set("deploymentReadyOption", om.valueToTree(this.getDeploymentReadyOption()));
            }
            if (this.getGreenFleetProvisioningOption() != null) {
                data.set("greenFleetProvisioningOption", om.valueToTree(this.getGreenFleetProvisioningOption()));
            }
            if (this.getTerminateBlueInstancesOnDeploymentSuccess() != null) {
                data.set("terminateBlueInstancesOnDeploymentSuccess", om.valueToTree(this.getTerminateBlueInstancesOnDeploymentSuccess()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@cdktf/provider-aws.codedeployDeploymentGroup.CodedeployDeploymentGroupBlueGreenDeploymentConfig"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CodedeployDeploymentGroupBlueGreenDeploymentConfig.Jsii$Proxy that = (CodedeployDeploymentGroupBlueGreenDeploymentConfig.Jsii$Proxy) o;

            if (this.deploymentReadyOption != null ? !this.deploymentReadyOption.equals(that.deploymentReadyOption) : that.deploymentReadyOption != null) return false;
            if (this.greenFleetProvisioningOption != null ? !this.greenFleetProvisioningOption.equals(that.greenFleetProvisioningOption) : that.greenFleetProvisioningOption != null) return false;
            return this.terminateBlueInstancesOnDeploymentSuccess != null ? this.terminateBlueInstancesOnDeploymentSuccess.equals(that.terminateBlueInstancesOnDeploymentSuccess) : that.terminateBlueInstancesOnDeploymentSuccess == null;
        }

        @Override
        public final int hashCode() {
            int result = this.deploymentReadyOption != null ? this.deploymentReadyOption.hashCode() : 0;
            result = 31 * result + (this.greenFleetProvisioningOption != null ? this.greenFleetProvisioningOption.hashCode() : 0);
            result = 31 * result + (this.terminateBlueInstancesOnDeploymentSuccess != null ? this.terminateBlueInstancesOnDeploymentSuccess.hashCode() : 0);
            return result;
        }
    }
}
